<?php
/*
 Plugin Name: Local Navigation
 Plugin URI:
 Description:
 Version: 1.2
 Author: Hiroshi Sato
 Author URI: http://blog.net-king.com
 */

global $wpdb, $local_navigation_table, $local_navigation_db_version;
$local_navigation_table = $wpdb->prefix.'local_navigation';
$local_navigation_db_version = '1.0';

//Switch PHP filename depending on version
function local_navigation_PHPfilename() {
	global $wp_version;
	if (version_compare($wp_version, "2.999", ">"))
		return "edit.php?post_type=page&page=local-navigation";
	else
		return "edit-pages.php?page=local-navigation";
}

function local_navigation_install(){
	global $wpdb, $local_navigation_table, $local_navigation_db_version;

	if($wpdb->get_var("SHOW TABLES LIKE '$local_navigation_table'") != $local_navigation_table) {
		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
			
		$sql = "CREATE TABLE " . $local_navigation_table . " (
		id mediumint( 9 ) NOT NULL AUTO_INCREMENT,
		name tinytext NOT NULL,
		text text NOT NULL,
		time bigint(11) DEFAULT '0' NOT NULL,
		UNIQUE KEY id (id)	
		);";
		dbDelta($sql);
		add_option("local_navigation_db_version", $local_navigation_db_version);
	}
}

register_activation_hook( __FILE__, 'local_navigation_install' );
//register_deactivation_hook (__FILE__, 'local_navigation_uninstall');

/*
 * 	Setting
 */
function local_navigation_pages() {
	if (function_exists('add_options_page')) {
		add_pages_page(__('Local Navigation', 'localnavigation'), __('Local Navigation', 'localnavigation'), 5, basename(__FILE__), 'local_navigation_options');
	}
}

add_action('admin_menu', 'local_navigation_pages');

function local_navigation_options() {
	global $wpdb, $local_navigation_table;
	isset($_GET['action']) ? $_action=$_GET['action']:$_action="showNavigations";
	
	if($_POST['navigation_name'] != '') {
		if($_POST['id'] =='') {
			$insert = "INSERT INTO " . $local_navigation_table .
			" (name, text, time) " .
			"VALUES ('" . $wpdb->escape($_POST['navigation_name']) . "','" . $wpdb->escape($_POST['navigation_text']) . "','" . time() . "')";
			$results = $wpdb->query($insert);
		}else{
			$update = "UPDATE " . $local_navigation_table .
			" set name = '".$wpdb->escape($_POST['navigation_name'])."', " .
			" text = '".$wpdb->escape($_POST['navigation_text'])."', " .
			" time = '".time()."' where id=".$wpdb->escape($_POST['id']);
			$results = $wpdb->query($update);
		}
		echo '<div id="message" class="updated fade" style="background-color: rgb(255, 251, 204);"><br/>'.__('Setting saved.', 'localnavigation').'<br/><br/></div>';
		echo '<script>document.location.href="'.local_navigation_PHPfilename().'";</script>';
	}
	if($_action == 'delete') {
		$delete = "DELETE FROM $local_navigation_table where id = ".$wpdb->escape($_GET['id']);
		$results = $wpdb->query($delete);
		echo '<div id="message" class="updated fade" style="background-color: rgb(255, 251, 204);"><br/>'.__('Setting deleted.', 'localnavigation').'<br/><br/></div>';
		echo '<script>document.location.href="'.local_navigation_PHPfilename().'";</script>';
		$_action = 'showNavigations';
	}
	if($_action == 'uninstall') {
		
		require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
		$sql = "DROP TABLE $local_navigation_table;";
		$wpdb->query($sql);
		delete_option("local_navigation_db_version");
		$allposts = get_posts( 'numberposts=-1&post_type=page&post_status=' );
		foreach( $allposts as $postinfo ) {
			delete_post_meta( $postinfo->ID, '_local_navigation_type' );
			delete_post_meta( $postinfo->ID, '_local_navigation_num' );
			delete_post_meta( $postinfo->ID, '_local_navigation_exclude' );
		}
		
	}
?>
<div class="wrap">
<h2><?php _e('Local Navigation', 'localnavigation') ?></h2>
	<?php
	switch($_action) {
		case 'showNavigations':
		if($wpdb->get_var("SHOW TABLES LIKE '$local_navigation_table'") != "") {
	?>
<script>
function localNavigation_deleteSetting(id){
	var cfm = confirm('<?php _e('You are going to delete this link, are you sure?', 'localnavigation'); ?>');
	if (cfm==true) window.location.href="<?php echo local_navigation_PHPfilename(); ?>&action=delete&id="+id;
}
function localNavigation_uninstallConfirm(){
	var cfm = confirm('<?php _e('Uninstall this plugin, are you sure?', 'localnavigation'); ?>');
	if (cfm==true) window.location.href="<?php echo local_navigation_PHPfilename(); ?>&action=uninstall";
}
</script>
<p>
	<a href="<?php echo local_navigation_PHPfilename(); ?>&action=edit" class="button"><?php _e('Add New', 'localnavigation'); ?></a>
</p>
<table class="widefat">
		<thead>
				<tr>
						<th><?php _e('Name'); ?></th>
						<th><?php _e('Edit'); ?></th>
						<th><?php _e('Delete'); ?></th>
				</tr>
		</thead>
		<?php
			$query = "select * from $local_navigation_table";
			$items = $wpdb->get_results($query);
			foreach($items as $item) {
				echo '<tr>';
				echo '<th>'.$item->name.'</th>';
				echo '<td><a href="'.local_navigation_PHPfilename().'&action=edit&id='.$item->id.'">'.(__('Edit')).'</a></td>';
				echo '<td><a href="javascript:localNavigation_deleteSetting('.$item->id.');">'.(__('Delete')).'</a></td>';
				echo '</tr>';
			}
			?>
</table>
<h2><?php _e('Uninstall', 'localnavigation'); ?></h2>
<?php _e('Delete the database and clear settings.', 'localnavigation'); ?>
<p>
	<a href="javascript:localNavigation_uninstallConfirm();" class="button"><?php _e('Clear Settings and Database', 'localnavigation'); ?></a>
</p>
		<?php
		}else{
			echo '<div id="message" class="updated fade" style="background-color: rgb(255, 251, 204);"><br/>'.__('Database deleted! now you can deactivate the plugin in plugins section.', 'localnavigation').'<br/><br/></div>';
		}
		break;

		case 'edit':
		$_value = '';
		if($_GET['id'] != '') {
			$query = "select `id`, `name`, `text` from $local_navigation_table where `id` = ".$wpdb->escape($_GET['id'])."";
			$_value = $wpdb->get_results($query);
		}
		?>
<h3><?php _e('Edit'); ?></h3>
<p>
	<a href="<?php echo local_navigation_PHPfilename(); ?>&action=showNavigations" class="button"><?php _e('Settings', 'localnavigation'); ?></a>
</p>
<form method="post" action="<?php echo local_navigation_PHPfilename(); ?>">
<input type="hidden" name="id" value="<?php echo $_value[0]->id; ?>" />
<?php wp_nonce_field('update-options'); ?>
<table class="form-table">
	<tr valign="top">
		<th scope="row"><?php _e('Name'); ?></th>
		<td><input type="text" name="navigation_name" value="<?php echo $_value[0]->name; ?>" /></td>
	</tr>
	<tr valign="top">
		<th scope="row"><?php _e('Text'); ?></th>
		<td>
			<textarea name="navigation_text" class="latge-text" cols="50" rows="10" style="width:90%"><?php echo stripslashes($_value[0]->text); ?></textarea>
			<div><?php _e('Arbitrary text, HTML, or PHP Code', 'localnavigation'); ?></div>
		</td>
	</tr>
	
</table>
<p class="submit"><input type="submit" class="button-primary"
		value="<?php _e('Save Changes') ?>" /></p>
</form>
	<?php
		break;
		
		case 'uninstall':
?>
<h3><?php _e('Uninstalled' ,'localnavigation'); ?></h3>
<?php _e('All settings and databese were removed and you can now go to the plugin menu and deactivate it.', 'localnavigation'); ?>
<a href="plugins.php" class="button"><?php _e('plugin menu', 'localnavigation'); ?> &raquo;</a>

<?php 
		break;
		
	}
?>

</div><!-- /wrap  -->

	<?php
}

/*
 * 	Page Edit
 */
add_action('admin_head', 'local_navigation_page_edit_options');

function local_navigation_page_edit_options(){
    add_meta_box('localnavdiv', __('Local Navigation', 'localnavigation'), 'local_navigation_meta_box', 'page', 'normal', 'high');
}

function local_navigation_meta_box($post){
	global $wpdb,$local_navigation_table;
	$post_custom = get_post_custom($post->ID);    
	$query = "select * from $local_navigation_table";
	$items = $wpdb->get_results($query);
	$_select = '<select name="local_navigation_num">';
	foreach($items as $item) {
		$_selected = ($post_custom['_local_navigation_num'][0] == $item->id) ? 'selected' : '';
		$_select .= '<option value="'.$item->id.'" '.$_selected.'>'.$item->name.'</option>';
		$_hidden .= '<textarea name="local_navigation_num_'.$item->id.'" style="display:none;">'.stripslashes($item->text).'</textarea>';
	}
	$_select .= '</select>';
	$post_custom = get_post_custom($post->ID);
	$_check = array();
	if(empty($post_custom['_local_navigation_type'][0])){ $post_custom['_local_navigation_type'][0] = 1; }
	($post_custom['_local_navigation_type'][0]) ? $_check[$post_custom['_local_navigation_type'][0]] = 'checked' : $_check[1] = 'checked';
	?>
	<p>
	<label><input type="radio" value="1" name="local_navigation_type" <?php echo $_check[1]; ?> />&nbsp; <?php echo __('Automatically create the localnavigation', 'localnavigation') ?></label><br />
	<?php if(count($items)>0): ?>
		<label><input type="radio" value="2" name="local_navigation_type" <?php echo $_check[2]; ?> />&nbsp; <?php echo __('Select Setting', 'localnavigation') ?></label>
		<?php echo $_select.$_hidden; ?><a href="javascript:void(0)" class="local-navigation-edit-text"><?php _e('Quick Edit'); ?></a><br />
		<div class="local-navigation-edit-textarea" style="display:none"><textarea rows="5" cols="40" name="local_navigation_edit_text" style="width:90%;"></textarea><p><?php _e('Save the setting after you have made changes to the page.', 'localnavigation'); ?><a href="javascript:void(0)" class="local-navigation-edit-close"><?php _e('Edit Cancel', 'localnavigation'); ?></a></p></div>
	<?php endif; ?>
	</p>
	<?php $checked = ($post_custom['_local_navigation_exclude'][0])? 'checked':''; ?>
	<p><label><input type="checkbox" name="local_navigation_exclude" <?php echo $checked; ?>>&nbsp;<?php _e('Exclude from the navigation.', 'localnavigation'); ?></label></p>
	<?php
}

add_action('save_post', 'local_navigation_update_post_settings');

function local_navigation_update_post_settings($id){
	if($_POST['post_type']!='page') return;
	$post_id = $_POST['post_ID'];
	if($_POST['local_navigation_type']){
		update_post_meta($post_id, '_local_navigation_type', $_POST['local_navigation_type']);
	}
	if($_POST['local_navigation_type'] == 2) {
			update_post_meta($post_id, '_local_navigation_num', $_POST['local_navigation_num']);
	}
	if($_POST['local_navigation_exclude']){
		update_post_meta($post_id, '_local_navigation_exclude',1);
	}else{
		delete_post_meta($post_id, '_local_navigation_exclude');
	}
	if($_POST['local_navigation_edit_text'] != '' && $_POST['local_navigation_type'] == 2) {
		global $wpdb,$local_navigation_table;
		$update = "UPDATE " . $local_navigation_table .
		" set text = '".$wpdb->escape($_POST['local_navigation_edit_text'])."', " .
		" time = '".time()."' where id=".$_POST['local_navigation_num'];
		$results = $wpdb->query($update);
	}
}

add_action('admin_head', local_navigation_js);

function local_navigation_js(){
?>
<script type="text/javascript">
	addLoadEvent(function(){
		jQuery('a.local-navigation-edit-text').click(localNavigationEdit);
		jQuery('a.local-navigation-edit-close').click(localNavigationEditClose);
		jQuery("select[name='local_navigation_num']").change(function(){
			jQuery("input[name='local_navigation_type']").val(["2"]);
		});
		jQuery(":submit").click(function(){
			jQuery("input[name='local_navigation_type']").removeAttr("disabled");
			jQuery("select[name='local_navigation_num']").removeAttr("disabled");
		});
	});
	function localNavigationEdit(){
		jQuery(".local-navigation-edit-textarea").show();
		jQuery("a.local-navigation-edit-text").hide();
		jQuery("input[name='local_navigation_type']").val(["2"]);
		editNum = jQuery("select[name='local_navigation_num']").val();
		editHtml = jQuery("textarea[name='local_navigation_num_"+editNum+"']").val();
		jQuery("textarea[name='local_navigation_edit_text']").val(editHtml);
		jQuery("input[name='local_navigation_type']").attr("disabled", "disabled");
		jQuery("select[name='local_navigation_num']").attr("disabled", "disabled");
	}
	function localNavigationEditClose(){
		jQuery(".local-navigation-edit-textarea").hide();
		jQuery("a.local-navigation-edit-text").show();
		jQuery("textarea[name='local_navigation_edit_text']").val("");
		jQuery("input[name='local_navigation_type']").removeAttr("disabled");
		jQuery("select[name='local_navigation_num']").removeAttr("disabled");
	}
</script>
<?php
}

/*
 *	Translation 
 */

add_action('init', 'local_navigation_loadtranslation');

function local_navigation_loadtranslation() {
	load_plugin_textdomain('localnavigation', PLUGINDIR.'/'.dirname(plugin_basename(__FILE__)).'/languages', dirname(plugin_basename(__FILE__)).'/languages');
}

/*
 * theme function
 */

function local_navigation_page_navigation($params='') {
	$default = array(
		'before_title' => '', 'after_title' => '',
	);
	$args = wp_parse_args( $params, $default );
	$localNavigationWidget = new local_navigation();
	$instance = array();
	if($args['hide_parent_title']==1||$args['hide_parent_title']=='true'||$args['hide_parent_title']=='TRUE') {
		$instance['hide_parent_title'] = 1;
	} 
	$localNavigationWidget->widget($args, $instance);
}

/*
 *	Widget 
 */

class local_navigation extends WP_Widget {

	function local_navigation() {
		$this->text_domain = get_class($this);
		load_textdomain ('localnavigation', DirName(__FILE__).'/languages/localnavigation-'.get_locale().'.mo');
		$widget_ops = array('classname' => 'local_navigation_widget', 'description' => __('Show Local Navigation', 'localnavigation'));
		$this->WP_Widget('local_navigation', __('Local Navigation', 'localnavigation'), $widget_ops, $control_ops);
	}

	function widget( $args, $instance ) {
		extract($args);
		if ( !is_page() ) return false;
		global $post, $local_navigation_table, $wpdb;
		$post_custom = get_post_custom($post->ID);
		if($post_custom['_local_navigation_type'][0] == 1 || $post_custom['_local_navigation_type'][0] == ''){
			if ($post->post_parent) { //child_post
				$parent = get_post($post->post_parent);
			}else{
				$parent = False;
			}
			$exclude = $wpdb->get_col("SELECT post_id FROM {$wpdb->postmeta} WHERE meta_key='_local_navigation_exclude' AND meta_value <> ''");
			$exclude = join(',', $exclude);
			$page_args = array(
				'title_li' => '',
				'child_of' => $post->ID,
				'exclude'  => $exclude,
				'depth'    => 1,
				'echo'     => 0,
			);
			if(!wp_list_pages($page_args)){
				if($parent){
					$page_args['child_of'] = $post->post_parent;
				}else{
					$page_args['child_of'] = '';
					$page_args['include'] = $post->ID;
				}
				$widgetTitle = $parent->post_title;
			}else{
				$widgetTitle = $post->post_title;
			}
			$ul_class = (empty($class))? 'local-navigation' : 'local-navigation '.$class;
			$list_pages = '<ul class="'.$ul_class.'">'.wp_list_pages($page_args).'</ul>';
		}elseif ($post_custom['_local_navigation_type'][0] == 2) {
			$query = "select `id`, `name`, `text` from $local_navigation_table where `id` = ".$wpdb->escape($post_custom['_local_navigation_num'][0])."";
			$result = $wpdb->get_results($query);
			ob_start();
			eval('?>'.stripslashes($result[0]->text));
			$list_pages = ob_get_contents();
			ob_end_clean();
		}
		$widgetTitle = ($parent) ? $widgetTitle : $post->post_title;
		echo $before_widget;
		if(!$instance['hide_parent_title']){ echo $before_title.$widgetTitle.$after_title; }
		echo $list_pages;
		echo $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['hide_parent_title'] = isset($new_instance['hide_parent_title']);
		return $instance;
	}

	function form( $instance ) {
		$default = array(
			'hide_parent_title' => '',
		);
		$instance = wp_parse_args( (array) $instance, $default );
		?>
<p><input id="<?php echo $this->get_field_id('hide_parent_title'); ?>"
		name="<?php echo $this->get_field_name('hide_parent_title'); ?>" type="checkbox"
		<?php checked(isset($instance['hide_parent_title']) ? $instance['hide_parent_title'] : 0); ?> />&nbsp;<label
		for="<?php echo $this->get_field_id('hide_parent_title'); ?>"><?php _e('Hide the title of the parent page.', 'localnavigation'); ?></label></p>
		<a href="<?php echo local_navigation_PHPfilename(); ?>"><?php _e('Setting', 'localnavigation'); ?></a>
		<?php
	}
} //class

add_action('widgets_init', create_function('', 'return register_widget("local_navigation");'));

// override 'wp_list_pages' functions
function local_navigation_wp_list_pages_excludes($exclude_array) {
    global $wpdb;
	$exclude_array = array_merge($exclude_array, $wpdb->get_col("SELECT post_id FROM {$wpdb->postmeta} WHERE meta_key='_local_navigation_exclude' AND meta_value <> ''"));
	return $exclude_array;
}
add_filter('wp_list_pages_excludes', 'local_navigation_wp_list_pages_excludes');

/*
 *	Short Code 
 */
function get_local_navigation($atts) {

	$derault = array(
		'before_title' => '',
		'after_title' => '',
	);
	$args = wp_parse_args( $atts, $default );

	ob_start();
	
	eval(local_navigation_page_navigation($args));
	$content_ul = ob_get_contents();
	ob_end_clean();

	$content = '';
	if(!empty($atts['div'])) {
		$content .= '<div class="'.esc_html($atts['div']).'">';
		$content .= $content_ul . '</div>';
	}else{
		$content .= $content_ul;
	}

	return $content;
}
add_shortcode('local_navigation', 'get_local_navigation');


